__version__ = "0.2.7"
__git_commiter_name__ = "Guy Rozendorn"
__git_commiter_email__ = "guy@rzn.co.il"
__git_branch__ = '(HEAD detached at v0.2.7)'
__git_remote_tracking_branch__ = '(No remote tracking)'
__git_remote_url__ = '(Not remote tracking)'
__git_head_hash__ = '29f08ed96a326627f9a5b3d095eb328c34ddece9'
__git_head_subject__ = 'Finished Release v0.2.7'
__git_head_message__ = '* develop:\n  Python 3 compatibility\n  update buildout.cfg\n  buildout.cfg: changed isolated python version to v2.7.6.21\n  buildout.cfg: changed isolated python version to v2.7.6.20\n  buildout.cfg: changed isolated python version to v2.7.6.19'
__git_dirty_diff__ = ''
__git_commit_date__ = '2016-02-15 14:02:39'
